[![Homepage](https://img.shields.io/badge/Homepage-github-white?logo=github)](https://github.com/WiredNerd/poodle)
[![python 3.10 - 3.14](https://img.shields.io/badge/python-3.10%20to%203.14-orange?logo=python&logoColor=green)](https://pypi.org/project/poodle)
[![PyPI - Version](https://img.shields.io/pypi/v/poodle?logo=pypi&logoColor=white)](https://pypi.org/project/poodle)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/poodle)](https://pypistats.org/packages/poodle)
[![PyPI - License](https://img.shields.io/pypi/l/poodle)](https://github.com/WiredNerd/poodle/blob/main/LICENSE)

[![Code Coverage](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fraw.githubusercontent.com%2FWiredNerd%2Fpoodle%2Fmain%2Fcode-coverage.json&query=%24.totals.percent_covered_display&suffix=%25&label=Code%20Coverage&color=teal&logo=pytest&logoColor=green)](https://pytest-cov.readthedocs.io)
[![Mutation Coverage](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fraw.githubusercontent.com%2FWiredNerd%2Fpoodle%2Fmain%2Fmutation-testing-report.json&query=%24.summary.coverage_display&logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64% &label=Mutation%20Coverage&color=3776b5)](https://poodle.readthedocs.io/)
[![Documentation](https://img.shields.io/badge/Read%20the%20Docs-Poodle-blue?logo=readthedocs&logoColor=FFF)](https://poodle.readthedocs.io/)

[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Code Style: black](https://img.shields.io/badge/Code_Style-Black-black?logo=python&logoColor=black)](https://black.readthedocs.io)
[![Linter: ruff](https://img.shields.io/badge/Linter-Ruff-purple?logo=Ruff)](https://beta.ruff.rs/docs/)
[![Snyk Security](https://img.shields.io/badge/Security-Snyk-939?logo=snyk)](https://snyk.io/)

# Poodle

Poodle is an tool for Mutation Testing your Python projects.

Mutation Testing proves the quality of your test suite by introducing bugs in your application, then verifying if your test cases can find the bug.

## Features

The goal of Poodle is to be highly efficient, configurable, and extendable.

* Multi-Threaded execution
* Highly Configurable (toml and py)
* Plug in custom code
* Output reports in Text, HTML, and JSON

## Quick Start

Installation:

```
pip install poodle --upgrade
```

```
Usage: poodle [OPTIONS] [SOURCES]...

  Poodle Mutation Test Tool.

Options:
  -c PATH             Configuration File.
  -q                  Quiet mode: q, qq, or qqq
  -v                  Verbose mode: v, vv, or vvv
  -w INTEGER          Maximum number of parallel workers.
  --exclude TEXT      Add a glob exclude file filter. Multiple allowed.
  --only TEXT         Glob pattern for files to mutate. Multiple allowed.
  --report TEXT       Enable reporter by name. Multiple allowed.
  --html PATH         Folder name to store HTML report in.
  --json PATH         File to create with JSON report.
  --fail_under FLOAT  Fail if mutation score is under this value.
  --version           Show the version and exit.
  --help              Show this message and exit.
```

## Documentation:

- https://poodle.readthedocs.io/

## Contribute

- Issue Tracker: https://github.com/WiredNerd/poodle/issues
- Source Code: https://github.com/WiredNerd/poodle

## Support

If you are having issues, please let us know.

I can be contacted at: pbuschmail-poodle@yahoo.com

Or by opening an issue: https://github.com/WiredNerd/poodle/issues

## License

The project is licensed under the MIT license.